<?php

namespace Domains\Support\Http\Controllers;
use Domains\Base\Http\Controllers\AppBaseController;
use Domains\Support\Http\Requests\CreateSupportChatRequest;
use Domains\Support\Http\Requests\UpdateSupportChatRequest;
use Domains\Support\Http\Resources\SupportChatResource;

use Domains\Support\Repositories\ChatRepository;
use Illuminate\Foundation\Auth\User;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;


class SupportChatController  extends AppBaseController
{

    /** @var  ChatRepository */
    private ChatRepository $chatRepository;

    public function __construct(ChatRepository $chatRepo)
    {
        $this->chatRepository = $chatRepo;
    }

    /**
     *
     *
     * @param Request $request
     * @return JsonResponse
     */
    public function index(Request $request): JsonResponse
    {
        $chats = $this->chatRepository->all(
            $request->except(['skip', 'limit']),
            $request->get('skip'),
            $request->get('limit')
        );

        if($request->get('support_question_id')){
            $chats = $chats->where('support_question_id',$request->get('support_question_id'));

        }

        if($request->get('support_chat_id')){
           $chats = $chats->where('support_chat_id',$request->get('support_chat_id'));

        }

        if($request->get('type')){
            $chats = $chats->where('type',$request->get('type'));

        }

        if ($request->user()?->role !='admin'){
            $chats = $chats->where('user_id',auth('sanctum')->id());
        }

        return $this->sendResponse(SupportChatResource::collection($chats), __('messages.retrieved', ['model' => __('models/support_chats.plural')]));
    }


    /**

     *
     * @param CreateSupportChatRequest $request
     *
     * @return JsonResponse
     */
    public function store(CreateSupportChatRequest $request): JsonResponse
    {
        $input = $request->all();
        $input['user_id'] = auth('sanctum')->id();
        $input['type'] = auth('sanctum')->user()->role;

        $chat = $this->chatRepository->create($input);

        return $this->sendResponse(new SupportChatResource($chat),__('messages.retrieved', ['model' => __('models/support_chats.plural')]));
    }




    /**
     * Display the specified Category.
     * GET|HEAD /categories/{id}
     *
     * @param int $id
     *
     * @return JsonResponse
     */
    public function show(int $id): JsonResponse
    {
        $chat = $this->chatRepository->findOrFail($id);


        return $this->sendResponse(new SupportChatResource($chat), __('messages.retrieved', ['model' => __('models/support_chats.plural')]));
    }

    /**
     * Update the specified Category in storage.
     * PUT/PATCH /categories/{id}
     *
     * @param int $id
     * @param UpdateSupportChatRequest $request
     *
     * @return JsonResponse
     */
    public function update(int $id, UpdateSupportChatRequest $request): JsonResponse
    {
        $chat = $this->chatRepository->findOrFail($id);
        $input = $request->all();
        $chat = $this->chatRepository->update($input, $id);

        return $this->sendResponse(new SupportChatResource($chat), __('messages.updated', ['model' => __('models/support_chats.plural')]));
    }

    public function activateToggle($id): JsonResponse
    {
        $chat = $this->chatRepository->findOrFail($id);
        $chat->active = !$chat->active;
        $chat->save();

        return $this->sendResponse(new SupportChatResource($chat), __('messages.updated', ['model' => __('models/support_chats.plural')]));
    }

    /**
     * Remove the specified Category from storage.
     * DELETE /categories/{id}
     *
     * @param int $id
     *
     * @return JsonResponse
     *
     */
    public function destroy(int $id): JsonResponse
    {
        $chat = $this->chatRepository->findOrFail($id);
        $chat->delete();

        return $this->sendResponse($id, __('messages.deleted', ['model' => __('models/support_chats.plural')]));
    }
}
