<?php

namespace Domains\Support\Http\Controllers;
use App\Models\User;
use Domains\Base\Http\Controllers\AppBaseController;
use Domains\Support\Http\Requests\CreateSupportMessageRequest;
use Domains\Support\Http\Requests\UpdateSupportMessageRequest;
use Domains\Support\Http\Resources\SupportMessageResource;
use Domains\Support\Models\Support_chat;
use Domains\Support\Repositories\MessageRepository;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;


class SupportMessageController extends AppBaseController
{

    /** @var  MessageRepository */
    private MessageRepository $messageRepository;

    public function __construct(MessageRepository $messageRepo)
    {
        $this->messageRepository = $messageRepo;
    }

    /**
     *
     *
     * @param Request $request
     * @return JsonResponse
     */
    public function index(Request $request): JsonResponse
    {
        $messages = $this->messageRepository->all(
            $request->except(['skip', 'limit']),
            $request->get('skip'),
            $request->get('limit')
        );

        if($request->get('support_chat_id')){
            $messages = $messages->where('support_chat_id',$request->get('support_chat_id'));
            }


        if($request->get('support_message_id')){
        $messages = $messages->where('support_message_id',$request->get('support_message_id'));
        }

        return $this->sendResponse(SupportMessageResource::collection($messages), __('messages.retrieved', ['model' => __('models/support_messages.plural')]));
    }


    /**

     *
     * @param CreateSupportMessageRequest $request
     *
     * @return JsonResponse
     */
    public function store(CreateSupportMessageRequest $request): JsonResponse
    {
        $input = $request->all();
        $input['sender_id'] = auth('sanctum')->id();
        $input['sender_type'] = auth('sanctum')->user()->role;

        if($request->file('file')){
            $input['file'] = $this->saveImage($request->file('file'), 'support_messages');
        }

        $message = $this->messageRepository->create($input);

        event(new \App\Events\SupportMessage(new SupportMessageResource($message)));

        if($request->user()->role =='admin'){
            $chat = Support_chat::find($message->support_chat_id);
            if($chat && $chat->user_id){
               $user = User::find($chat->user_id);
               $user->notify(new \App\Notifications\Message($message));

               if($user->token){
                sendFirebaseNotification($user->token,__('models/support_messages.singular'),new \App\Notifications\Message($message));
               }
        }

        }

        else{
            $user = User::where('role','admin')->first();
            $user->notify(new \App\Notifications\Message($message));
        }


        return $this->sendResponse(new SupportMessageResource($message),__('messages.retrieved', ['model' => __('models/support_messages.plural')]));
    }



    /**
     * Display the specified Category.
     * GET|HEAD /categories/{id}
     *
     * @param int $id
     *
     * @return JsonResponse
     */
    public function show(int $id): JsonResponse
    {
        $message = $this->messageRepository->findOrFail($id);

        return $this->sendResponse(new SupportMessageResource($message), __('messages.retrieved', ['model' => __('models/support_messages.plural')]));
    }

    /**
     * Update the specified Category in storage.
     * PUT/PATCH /categories/{id}
     *
     * @param int $id
     * @param UpdateSupportMessageRequest $request
     *
     * @return JsonResponse
     */
    public function update(int $id, UpdateSupportMessageRequest $request): JsonResponse
    {
        $message = $this->messageRepository->findOrFail($id);
        $input = $request->all();
        $message = $this->messageRepository->update($input, $id);

        return $this->sendResponse(new SupportMessageResource($message), __('messages.updated', ['model' => __('models/support_messages.plural')]));
    }

    public function activateToggle($id): JsonResponse
    {
        $message = $this->messageRepository->findOrFail($id);
        $message->active = !$message->active;
        $message->save();

        return $this->sendResponse(new SupportMessageResource($message), __('messages.updated', ['model' => __('models/support_messages.plural')]));
    }

    /**
     * Remove the specified Category from storage.
     * DELETE /categories/{id}
     *
     * @param int $id
     *
     * @return JsonResponse
     *
     */
    public function destroy(int $id): JsonResponse
    {
        $message = $this->messageRepository->findOrFail($id);
        $message->delete();

        return $this->sendResponse($id, __('messages.deleted', ['model' => __('models/support_messages.plural')]));
    }
}
