<?php

namespace Domains\Support\Http\Controllers;
use Domains\Base\Http\Controllers\AppBaseController;
use Domains\Support\Http\Requests\CreateSupportQuestionRequest;
use Domains\Support\Http\Requests\UpdateSupportQuestionRequest;
use Domains\Support\Http\Resources\SupportQuestionResource;
use Domains\Support\Repositories\QuestionRepository;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;


class SupportQuestionController extends AppBaseController
{

    /** @var  QuestionRepository */
    private QuestionRepository $questionRepository;

    public function __construct(QuestionRepository $questionRepo)
    {
        $this->questionRepository = $questionRepo;
    }

    /**
     *
     *
     * @param Request $request
     * @return JsonResponse
     */
    public function index(Request $request): JsonResponse
    {
        $questions = $this->questionRepository->all(
            $request->except(['skip', 'limit']),
            $request->get('skip'),
            $request->get('limit')
        )->where('type',$request->get('type'));

        return $this->sendResponse(SupportQuestionResource::collection($questions), __('messages.retrieved', ['model' => __('models/support_questions.plural')]));
    }


    /**

     *
     * @param CreateQuestionRequest $request
     *
     * @return JsonResponse
     */
    public function store(CreateSupportQuestionRequest $request): JsonResponse
    {
        $input = $request->all();
        $question = $this->questionRepository->create($input);

        return $this->sendResponse(new SupportQuestionResource($question),__('messages.retrieved', ['model' => __('models/support_questions.plural')]));
    }



    /**
     * Display the specified Category.
     * GET|HEAD /categories/{id}
     *
     * @param int $id
     *
     * @return JsonResponse
     */
    public function show(int $id): JsonResponse
    {
        $question = $this->questionRepository->findOrFail($id);

        return $this->sendResponse(new SupportQuestionResource($question), __('messages.retrieved', ['model' => __('models/support_questions.plural')]));
    }

    /**
     * Update the specified Category in storage.
     * PUT/PATCH /categories/{id}
     *
     * @param int $id
     * @param UpdateSupportQuestionRequest $request
     *
     * @return JsonResponse
     */
    public function update(int $id, UpdateSupportQuestionRequest $request): JsonResponse
    {
        $questions = $this->questionRepository->findOrFail($id);
        $input = $request->all();






        $questions = $this->questionRepository->update($input, $id);

        return $this->sendResponse(new SupportQuestionResource($questions), __('messages.updated', ['model' => __('models/support_questions.plural')]));
    }

    public function activateToggle($id): JsonResponse
    {
        $question = $this->questionRepository->findOrFail($id);
        $question->active = !$question->active;
        $question->save();

        return $this->sendResponse(new SupportQuestionResource($question), __('messages.updated', ['model' => __('models/support_questions.plural')]));
    }

    /**
     * Remove the specified Category from storage.
     * DELETE /categories/{id}
     *
     * @param int $id
     *
     * @return JsonResponse
     *
     */
    public function destroy(int $id): JsonResponse
    {
        $question = $this->questionRepository->findOrFail($id);
        $question->delete();

        return $this->sendResponse($id, __('messages.deleted', ['model' => __('models/support_questions.plural')]));
    }
}
