<?php

namespace Domains\Terms\Http\Controllers;
use Domains\Base\Http\Controllers\AppBaseController;
use Domains\Terms\Http\Requests\CreateTermRequest;
use Domains\Terms\Http\Requests\GetTermsRequest;
use Domains\Terms\Http\Requests\UpdateTermRequest;
use Domains\Terms\Http\Resources\GetTermsResource;
use Domains\Terms\Http\Resources\TermResource;
use Domains\Terms\Models\Term;
use Domains\Terms\Repositories\TermRepository;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;


class TermController extends AppBaseController
{

    /** @var  TermRepository */
    private TermRepository $TermRepository;

    public function __construct(TermRepository $TermRepository)
    {
        $this->TermRepository = $TermRepository;
    }

    /**
     *
     * @param Request $request
     * @return JsonResponse
     */
    public function index(Request $request): JsonResponse
    {
        $terms = $this->TermRepository->all(
            $request->except(['skip', 'limit']),
            $request->get('skip'),
            $request->get('limit')
        );

        if($request->get('term_id')){
        $terms = $terms->where('term_id',$request->get('term_id'));
        }

        return $this->sendResponse(TermResource::collection($terms), __('messages.retrieved', ['model' => __('models/terms.plural')]));
    }

    
    /**
     * @param CreateTermRequest $request
     *
     * @return JsonResponse
     */
    public function store(CreateTermRequest $request): JsonResponse
    {
        $input = $request->all();
        $term = $this->TermRepository->create($input);

        return $this->sendResponse(new TermResource($term),__('messages.retrieved', ['model' => __('models/terms.singular')]));
    }



    public function show(int $id): JsonResponse
    {
        $term= $this->TermRepository->findOrFail($id);

        return $this->sendResponse(new TermResource($term), __('messages.retrieved', ['model' => __('models/terms.singular')]));
    }

    /**
     *
     * @param int $id
     * @param UpdateTermRequest $request
     *
     * @return JsonResponse
     */
    public function update(int $id, UpdateTermRequest $request): JsonResponse
    {
        $term = $this->TermRepository->findOrFail($id);
        $input = $request->all();
        $term = $this->TermRepository->update($input, $id);

        return $this->sendResponse(new TermResource($term), __('messages.updated', ['model' => __('models/terms.singular')]));
    }

    public function activateToggle($id): JsonResponse
    {
        $term = $this->TermRepository->findOrFail($id);
        $term->active = !$term->active;
        $term->save();

        return $this->sendResponse(new TermResource($term), __('messages.updated', ['model' => __('models/terms.singular')]));
    }

   
    public function destroy(int $id): JsonResponse
    {
        $term = $this->TermRepository->findOrFail($id);
        $term->delete();

        return $this->sendResponse($id, __('messages.deleted', ['model' => __('models/terms.singular')]));
    }

    public function getTerms(GetTermsRequest $request)
    {
        $terms = Term::whereHas('country', function($query) use ($request){
            $query->where('country_code', $request->country);
        })->where('active', true)->get();
        return $this->sendResponse(GetTermsResource::collection($terms), __('messages.retrieved', ['model' => __('models/terms.plural')]));
    }
}
